LiveDebugger

Trait LiveDebugger 

pub trait LiveDebugger: Send + Sync {
    // Required methods
    fn send(&self, cmd: &str) -> Result<String>;
    fn tool_name(&self) -> &'static str;
}
A minimal handle the daemon passes to collectors so they can issue commands on the live debugger session when useful. None when the collector is invoked from a profile-only context (no live PTY).

Required Methods

fn send(&self, cmd: &str) -> Result<String>

Send a native-tool command to the active debugger and return its (cleaned) output.

fn tool_name(&self) -> &'static str

Tool name, for logging / error messages.

Implementors