pub trait LiveDebugger: Send + Sync {
// Required methods
fn send(&self, cmd: &str) -> Result<String>;
fn tool_name(&self) -> &'static str;
}Expand description
A minimal handle the daemon passes to collectors so they can issue commands on the live debugger session when useful. None when the collector is invoked from a profile-only context (no live PTY).